==> xwiki-web-gwt-dom-2.0.3.jar: org/xwiki/gwt/dom/client/internal/mozilla/MozillaSelectionManager.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.gwt.dom.client.internal.mozilla;

import org.xwiki.gwt.dom.client.Document;
import org.xwiki.gwt.dom.client.Selection;
import org.xwiki.gwt.dom.client.SelectionManager;

/**
 * Implements {@link SelectionManager} for Firefox prior to version 3.0.
 * 
 * @version $Id: MozillaSelectionManager.java 20042 2009-05-16 12:12:50Z sdumitriu $
 */
public class MozillaSelectionManager implements SelectionManager
{
    /**
     * {@inheritDoc}
     * 
     * @see SelectionManager#getSelection(Document)
     */
    public Selection getSelection(Document document)
    {
        return new MozillaSelection(NativeSelection.getInstance(document));
    }
}

==> xwiki-web-gwt-dom-2.0.4.jar: org/xwiki/gwt/dom/client/internal/mozilla/MozillaSelectionManager.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.gwt.dom.client.internal.mozilla;

import org.xwiki.gwt.dom.client.Document;
import org.xwiki.gwt.dom.client.Selection;
import org.xwiki.gwt.dom.client.SelectionManager;

/**
 * Implements {@link SelectionManager} for Mozilla browsers.
 * 
 * @version $Id: MozillaSelectionManager.java 25109 2009-11-17 23:22:09Z mflorea $
 */
public class MozillaSelectionManager implements SelectionManager
{
    /**
     * {@inheritDoc}
     * 
     * @see SelectionManager#getSelection(Document)
     */
    public Selection getSelection(Document document)
    {
        return new MozillaSelection(NativeSelection.getInstance(document));
    }
}
